@@ -8,13 +8,18 @@ import logging
 import datetime
 import itertools
 from pathlib import Path
+import shlex
 
 import numpy as np
 import pandas as pd
 
-# This import is seemingly not used, but necessary for some attributes
-# to be included in DeckItem objects.
-from opm.io.deck import DeckKeyword  # noqa
+try:
+    # This import is seemingly not used, but necessary for some attributes
+    # to be included in DeckItem objects.
+    from opm.io.deck import DeckKeyword  # noqa
+except ImportError:
+    # Allow parts of ecl2df to work without OPM:
+    pass
 
 from ecl2df import __version__
 
@@ -617,3 +622,45 @@ def stack_on_colnames(dframe, sep="@", stackcolname="DATE", inplace=True):
     del dframe["level_0"]
     dframe.index.name = ""
     return dframe
+
+
+def parse_zonemapfile(filename: str):
+    """Return a dictionary from (int) K layers in the simgrid to strings
+
+    Typical usage is to map from grid layer to zone names.
+
+    The layer filename must currently follow format:
+
+      'ZoneA' 1-4
+      'ZoneB' 5-10
+
+    where the single quotes are optional for zones without spaces.
+    Write single layer zones as 11-11. NB: ResInsight requires single
+    quotes always.
+
+    Either "--" or "#" can be used to denote comments.
+
+    Args:
+        filename (str): Absolute path to a zone map file (lyr format)
+
+    Returns:
+        dict, integer keys which are the K layers. Every layer mentioned
+            in the interval in the input file is present. Can be empty.
+    """
+    zonelines = Path(filename).read_text().splitlines()
+
+    # Remove comments, support both "--" and "#":
+    zonelines = [line.split("--")[0].strip() for line in zonelines]
+    zonelines = [line for line in zonelines if line and not line.startswith("#")]
+
+    zonemap = {}
+    for line in zonelines:
+        try:
+            linesplit = shlex.split(line)
+            (k_0, k_1) = "".join(linesplit[1:]).split("-")
+            zonemap.update(dict.fromkeys(range(int(k_0), int(k_1) + 1), linesplit[0]))
+        except ValueError:
+            logger.error("Could not parse zonemapfile %s", filename)
+            logger.error("Failed on content: %s", line)
+            return None
+    return zonemap
