@@ -1,8 +1,8 @@
 """Support module for extra files with key-value information
 related to Eclipse runs"""
 
-import os
 import logging
+from pathlib import Path
 
 import json
 import yaml
@@ -10,7 +10,6 @@ import pandas as pd
 
 from ecl2df.eclfiles import EclFiles
 
-logging.basicConfig()
 logger = logging.getLogger(__name__)
 
 
@@ -33,9 +32,9 @@ def find_parameter_files(ecldeck_or_eclpath, filebase="parameters"):
            found
     """
     if isinstance(ecldeck_or_eclpath, EclFiles):
-        eclbasepath = ecldeck_or_eclpath.get_path()
+        eclbasepath = Path(ecldeck_or_eclpath.get_path())
     elif isinstance(ecldeck_or_eclpath, str):
-        eclbasepath = os.path.abspath(os.path.dirname(ecldeck_or_eclpath))
+        eclbasepath = Path(ecldeck_or_eclpath).parent.absolute()
     else:
         raise TypeError
     files_to_lookfor = [
@@ -44,12 +43,12 @@ def find_parameter_files(ecldeck_or_eclpath, filebase="parameters"):
         filebase + ".txt",
         filebase,
     ]
-    paths_to_check = [os.curdir, os.pardir, os.path.join(os.pardir, os.pardir)]
+    paths_to_check = [".", "..", Path("..") / Path("..")]
     foundfiles = []
     for path in paths_to_check:
         for fname in files_to_lookfor:
-            fullfname = os.path.join(eclbasepath, path, fname)
-            if os.path.exists(fullfname):
+            fullfname = eclbasepath / path / fname
+            if fullfname.is_file():
                 foundfiles.append(fullfname)
     return foundfiles
 
@@ -116,7 +115,7 @@ def load(filename):
         if not isinstance(params_dict, dict):
             # yaml happily parses txt files into a single line, don't want that.
             params_dict = None
-    except Exception as yaml_error:
+    except Exception as yaml_error:  # noqa
         logger.debug("%s was not parseable with yaml, trying json.", filename)
 
     json_error = ""
@@ -126,7 +125,7 @@ def load(filename):
             params_dict = json.load(open(filename))
             assert isinstance(params_dict, dict)
             logger.debug(" - ok, parsed as yaml")
-        except Exception as json_error:
+        except Exception as json_error:  # noqa
             logger.debug("%s was not parseable with json, trying txt.", filename)
 
     txt_error = ""
@@ -136,20 +135,20 @@ def load(filename):
             params_dict = load_parameterstxt(filename)
             assert isinstance(params_dict, dict)
             logger.debug(" - ok, parsed as txt")
-        except Exception as txt_error:
+        except Exception as txt_error:  # noqa
             logger.debug("%s wat not parseable as txt, no more options", filename)
 
     if not params_dict:
         logger.warning("%s could not be parsed as yaml, json or txt", filename)
         logger.warning("%s%s%s", str(yaml_error), str(json_error), str(txt_error))
         raise ValueError("Could not parse {}".format(filename))
-    else:
-        # Filter to values that are NOT dict's. We can have dict as value when
-        # "grouped" keys are present in the json files, both as "group:key value"
-        # and in a dict called group
-        params_dict = {
-            key: value
-            for (key, value) in params_dict.items()
-            if not isinstance(value, dict)
-        }
-        return params_dict
+
+    # Filter to values that are NOT dict's. We can have dict as value when
+    # "grouped" keys are present in the json files, both as "group:key value"
+    # and in a dict called group
+    params_dict = {
+        key: value
+        for (key, value) in params_dict.items()
+        if not isinstance(value, dict)
+    }
+    return params_dict
